@@ -9,6 +9,12 @@ async def test_unimplemented_make_request():
         await inverter.Inverter.make_request('localhost', 80)
 
 
+@pytest.mark.asyncio
+async def test_unimplemented_make_request_with_pwd():
+    with pytest.raises(NotImplementedError):
+        await inverter.Inverter.make_request('localhost', 80, 'pwd')
+
+
 def test_unimplemented_sensor_map():
     with pytest.raises(NotImplementedError):
         inverter.Inverter.sensor_map()
